@@ -61,7 +61,7 @@ class RDBService:
             cusor.execute(sql)
             self.conn.commit()
             cusor.close()
-            logging.debug("New a record into {}: {}".format(table, data))
+            #logging.debug("New a record into {}: {}".format(table, data))
         except Exception as e:
             traceback.print_exc()
             self.close()
@@ -100,7 +100,7 @@ class RDBService:
             cusor.execute(sql)
             self.conn.commit()
             cusor.close()
-            logging.debug('数据更新成功!')
+            #logging.debug('数据更新成功!')
 
         except Exception as e:
             traceback.print_exc()
@@ -115,7 +115,7 @@ class RDBService:
             res = cusor.execute(sql)
             self.conn.commit()
             cusor.close()
-            logging.debug('数据删除成功！')
+            #logging.debug('数据删除成功！')
         except Exception as e:
             traceback.print_exc()
             self.close()
@@ -140,7 +140,8 @@ class RDBService:
         if isinstance(var, int) or isinstance(var, float):
             return str(var)
         elif isinstance(var,Decimal):
-            return str(round(var,2))
+            #return str(round(var,2))
+            return str(var)
         else:
             return '\'{}\''.format(var)
 
